<?php
/**
 * Sleepybeargummies functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Sleepybeargummies
 */

if ( ! function_exists( 'sleepybeargummies_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function sleepybeargummies_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Sleepybeargummies, use a find and replace
		 * to change 'sleepybeargummies' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'sleepybeargummies', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'home-thumb',370 ,386 ,true );
		add_image_size( 'testimonial-thumb',206 ,206 ,true );
		add_image_size( 'team-single-thumb',655 ,436 ,true );
		add_image_size( 'team-thumb',331 ,304 ,true );
		//add_image_size( 'overview-img',1024 ,629 ,true );
		//add_image_size( 'overview-img',838 ,506 ,true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'main-menu' 	=> esc_html__( 'Main Menu', 'sleepybeargummies' ),
			'footer-links' 	=> esc_html__( 'Footer Links', 'sleepybeargummies' ),
			'social-links' 	=> esc_html__( 'Social Links', 'sleepybeargummies' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 354,
			'width'       => 360,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		
		/* making theme compatible with woocommerce */
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
        add_theme_support( 'wc-product-gallery-lightbox' );
        add_theme_support( 'wc-product-gallery-slider' );

	}
endif;
add_action( 'after_setup_theme', 'sleepybeargummies_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sleepybeargummies_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'sleepybeargummies_content_width', 640 );
}
add_action( 'after_setup_theme', 'sleepybeargummies_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sleepybeargummies_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'sleepybeargummies' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'sleepybeargummies' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	/*for ($i=1; $i < 3; $i++) { 
		register_sidebar( array(
			'name'          => esc_html__( 'Footer '.$i, 'sleepybeargummies' ),
			'id'            => 'footer-'.$i,
			'description'   => esc_html__( 'Add widgets here.', 'sleepybeargummies' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s footer-contact-content">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}*/

}
add_action( 'widgets_init', 'sleepybeargummies_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function sleepybeargummies_scripts() {
	wp_enqueue_style( 'sleepybeargummies-google-fonts', '//fonts.googleapis.com/css?family=Open+Sans:wght@400;600;700;800&display=swap', false );
	wp_enqueue_style( 'sleepybeargummies-slick-theme', get_template_directory_uri() . '/assets/css/slick-theme.css' );	
	wp_enqueue_style( 'sleepybeargummies-slick', get_template_directory_uri() . '/assets/css/slick.css' );	
	wp_enqueue_style( 'sleepybeargummies-meanmenu', get_template_directory_uri() . '/assets/css/meanmenu.css' );
	wp_enqueue_style( 'sleepybeargummies-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css' );
	wp_enqueue_style( 'sleepybeargummies-style', get_stylesheet_uri(), '', time() );
	wp_enqueue_style( 'sleepybeargummies-responsive', get_template_directory_uri() . '/assets/css/responsive.css', '', time() );

	wp_enqueue_script( 'sleepybeargummies-bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ), time(), true );	
	wp_enqueue_script( 'sleepybeargummies-bootstrap.map', '//maxcdn.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js.map' );
	wp_enqueue_script( 'sleepybeargummies-slick', get_template_directory_uri() . '/assets/js/slick.js', array( 'jquery' ), time(), true );	
	wp_enqueue_script( 'sleepybeargummies-jquery.meanmenu', get_template_directory_uri() . '/assets/js/jquery.meanmenu.js', array( 'jquery' ), time(), true );	
	wp_enqueue_script( 'sleepybeargummies-custom.js', get_template_directory_uri() . '/assets/js/custom.js', array( 'jquery' ), time(), true );

	if ( is_front_page() ) {
		wp_enqueue_script( 'sleepybeargummies-homepage.js', get_template_directory_uri() . '/assets/js/homepage.js', array( 'jquery' ), time(), true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sleepybeargummies_scripts' );

/**
 * Implement the Custom function where additional files are added.
 */
require get_template_directory() . '/inc/init.php';

/* CS get all theme options */
if ( ! function_exists( 'get_theme_option' ) ) {
  	function get_theme_option( $option = '', $default = null ) {

    	// Attention: Its your unique id of the framework
    	$options = get_option( 'theme_options' );

		return ( isset( $options[$option] ) ) ? $options[$option] : $default;

	}
}

//replace Δ	Delta with html code &Delta;
if( ! function_exists( 'sanitize_delta' ) ) {
	function sanitize_delta( $value ) {
		return str_replace( 'Δ', '&Delta;', $value );
	}
}

// add_filter('add_to_cart_redirect', 'sleepybeargummies_add_to_cart_redirect');
// function sleepybeargummies_add_to_cart_redirect() {
//     global $woocommerce;
//     $sleepybeargummies_redirect_checkout = $woocommerce->cart->get_checkout_url();
//     return $sleepybeargummies_redirect_checkout;
// }

//change text on the single product page
function wcsatt_price_html_args( $args, $product, $scheme_key ) {
     $args['subscribe_for_html'] = 'Subscribe and Save 20&#37; %s';
     return $args;
}
add_filter( 'wcsatt_price_html_args', 'wcsatt_price_html_args', 10, 3 );


// Add body class for specific page.
function sleepybear_custom_body_class( $classes ) {
	if ( is_page( 'day-bear' ) ) {
		$classes[] = 'is-day-view';
	}

	return $classes;
}
add_filter( 'body_class', 'sleepybear_custom_body_class' );

/**
* Removes or edits the 'Protected:' part from posts titles
*/
 
function remove_protected_text() {
    return '%s';
}
add_filter( 'protected_title_format', 'remove_protected_text' );

