<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Sleepybeargummies
 */

if ( ! function_exists( 'sleepybeargummies_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function sleepybeargummies_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( '%s', 'post date', 'sleepybeargummies' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		//echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'sleepybeargummies_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function sleepybeargummies_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( '%s', 'post author', 'sleepybeargummies' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'sleepybeargummies_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function sleepybeargummies_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'sleepybeargummies' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( '%1$s', 'sleepybeargummies' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'sleepybeargummies' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'In %1$s', 'sleepybeargummies' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		/*if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						//translators: %s: post title
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'sleepybeargummies' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					//translators: %s: Name of current post. Only visible to screen readers
					__( 'Edit <span class="screen-reader-text">%s</span>', 'sleepybeargummies' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);*/
	}
endif;

if ( ! function_exists( 'sleepybeargummies_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function sleepybeargummies_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
			the_post_thumbnail( 'post-thumbnail', array(
				'alt' => the_title_attribute( array(
					'echo' => false,
				) ),
			) );
			?>
		</a>

		<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;

/**
 * Additomal Custom Functions.
 * custom taxonomy (theme category) display
 */
if ( ! function_exists( 'sleepybeargummies_theme_category' ) ) :
    function sleepybeargummies_theme_category() {
        echo get_the_term_list( get_the_ID(), 'themes_categories', '', ' - ', '' );
    }
endif;

/**
 * Returns the url of image
 * @param  [array] $param 
 * @return string
 */
function sleepybeargummies_image_src( $param ) {

    if( !is_array( $param ) ) {
        return;
    }
    if ( empty ( $param['size'] ) ){

        $param['size']  = 'full' ;
    }
    $image = wp_get_attachment_image_src( $param['id'], $param['size'] );
    
    return $image[0];
}

function sleepybeargummies_excerpt( $length = 60, $post_object = null ) {
    global $post;
    if( is_null( $post_object ) ) {
        $post_object = $post;
    }
    $length      = absint( $length );
    if( $length < 1 ) {
        $length      = 60;
    }
    $content     = strip_shortcodes( $post_object->post_content );
    $excerpt     = trim( wp_trim_words( $content, $length, '...' ) );
    return $excerpt;
}

//created breadcrum function
if( ! function_exists( 'sleepybeargummies_simple_breadcrumb' ) ) :
    /**
     * Simple breadcrumb
     * Source: https://gist.github.com/melissacabral/4032941
     */
    function sleepybeargummies_simple_breadcrumb( $args = array() ){
        $args = wp_parse_args( (array) $args, array(
            //'separator' =>  '&gt;',
            'separator' =>  '',
        ) );

        /* === OPTIONS === */
        //$text['home']     = get_bloginfo( 'name' ); // text for the 'Home' link
        $text['home']     = 'Home'; // text for the 'Home' link
        $text['category'] = __( 'Archive for <em>%s</em>', 'sleepybeargummies' ); // text for a category page
        $text['tax']      = __( 'Archive for <em>%s</em>', 'sleepybeargummies' ); // text for a taxonomy page
        $text['search']   = __( 'Search results for: <em>%s</em>', 'sleepybeargummies' ); // text for a search results page
        $text['tag']      = __( 'Posts tagged <em>%s</em>', 'sleepybeargummies' ); // text for a tag page
        $text['author']   = __( 'View all posts by <em>%s</em>', 'sleepybeargummies' ); // text for an author page
        $text['404']      = __( 'Error 404', 'sleepybeargummies' ); // text for the 404 page

        $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
        $showOnHome  = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
        $delimiter   = ' ' . $args['separator'] . ' '; // delimiter between crumbs
        $before      = '<li class="current"><span>'; // tag before the current crumb
        $after       = '</span></li>'; // tag after the current crumb
        /* === END OF OPTIONS === */

        global $post;
        $homeLink   = esc_url( home_url( '/' ) );
        $linkBefore = '<li typeof="v:Breadcrumb">';
        $linkAfter  = '</li>';
        $linkAttr   = ' rel="v:url" property="v:title"';
        $link       = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;

        if (is_home() || is_front_page()) {

            if ($showOnHome == 1) echo '<ol class="breadcrumb"><li><a href="' . $homeLink . '">' . $text['home'] . '</a></li></div>';

        } else {

            echo '<ol class="breadcrumb" xmlns:v="http://rdf.data-vocabulary.org/#">' . sprintf($link, $homeLink, $text['home']) . $delimiter;

            if ( is_category() ) {
                $thisCat = get_category(get_query_var('cat'), false);
                if ($thisCat->parent != 0) {
                    $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
                    $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                    $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                    echo $cats;
                }
                echo $before . sprintf($text['category'], single_cat_title('', false)) . $after;

            } elseif ( is_search() ) {
                echo $before . sprintf($text['search'], get_search_query()) . $after;

            } elseif ( is_day() ) {
                echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
                echo sprintf($link, get_month_link(get_the_time('Y'),get_the_time('m')), get_the_time('F')) . $delimiter;
                echo $before . get_the_time('d') . $after;

            } elseif ( is_month() ) {
                echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
                echo $before . get_the_time('F') . $after;

            } elseif ( is_year() ) {
                echo $before . get_the_time('Y') . $after;

            } elseif ( is_single() && !is_attachment() ) {
                if ( get_post_type() != 'post' ) {
                    $post_type = get_post_type_object(get_post_type());
                    $slug = $post_type->rewrite;
                    /*echo '<pre>';
                        print_r($post_type);
                    echo '</pre>';*/
                    printf($link, $homeLink . '/' . $slug['slug'] . 's/', $post_type->labels->name);

                    if ($showCurrent == 1) echo $delimiter . $before . get_the_title() . $after;
                } else {
                    $cat = get_the_category(); $cat = $cat[0];
                    $cats = get_category_parents($cat, TRUE, $delimiter);
                    if ($showCurrent == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
                    $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                    $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                    echo  $cats;
                    if ($showCurrent == 1) echo $before . get_the_title() . $after;
                }


            } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
                $post_type = get_post_type_object(get_post_type());
                echo $before . $post_type->labels->singular_name . $after;

            } elseif ( is_attachment() ) {
                $parent = get_post($post->post_parent);
                $cat = get_the_category($parent->ID); $cat = $cat[0];
                $cats = get_category_parents($cat, TRUE, $delimiter);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo $cats;
                printf($link, get_permalink($parent), $parent->post_title);
                if ($showCurrent == 1) echo $delimiter . $before . get_the_title() . $after;

            } elseif ( is_page() && !$post->post_parent ) {
                if ($showCurrent == 1) echo $before . get_the_title() . $after;

            } elseif ( is_page() && $post->post_parent ) {
                $parent_id  = $post->post_parent;
                $breadcrumbs = array();
                while ($parent_id) {
                    $page = get_page($parent_id);
                    $breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
                    $parent_id  = $page->post_parent;
                }
                $breadcrumbs = array_reverse($breadcrumbs);
                for ($i = 0; $i < count($breadcrumbs); $i++) {
                    echo $breadcrumbs[$i];
                    if ($i != count($breadcrumbs)-1) echo $delimiter;
                }
                if ($showCurrent == 1) echo $delimiter . $before . get_the_title() . $after;

            } elseif ( is_tag() ) {
                echo $before . sprintf($text['tag'], single_tag_title('', false)) . $after;

            } elseif ( is_author() ) {
                global $author;
                $userdata = get_userdata($author);
                echo $before . sprintf($text['author'], $userdata->display_name) . $after;

            } elseif ( is_404() ) {
                echo $before . $text['404'] . $after;
            }

            /* if ( get_query_var('paged') ) {
                if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
                echo __( 'Page', 'sleepybeargummies' ) . ' ' . get_query_var('paged');
                if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
            } */

            echo '</ol>';
        }
    } // end sleepybeargummies_simple_breadcrumb()
endif;

function setPostViews($postID) {
    $countKey = 'post_views_count';
    $count = get_post_meta($postID, $countKey, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $countKey);
        add_post_meta($postID, $countKey, '0');
    }else{
        $count++;
        update_post_meta($postID, $countKey, $count);
    }
     return absint( $count ).' Views';
}

add_filter( 'get_the_archive_title', function ($title) {    
    if ( is_category() ) {    
            $title = single_cat_title( '', false );    
        } elseif ( is_tag() ) {    
            $title =  single_tag_title( '', false ) ;
        } elseif ( is_author() ) {    
            $title = '<span class="vcard">' . get_the_author() . '</span>' ;    
        } elseif ( is_tax() ) { //for custom post types
            $title = sprintf( __( '%1$s' ), single_term_title( '', false ) );
        } elseif (is_post_type_archive()) {
            $title = post_type_archive_title( '', false );
        } 
    return $title;    
});

function sleepybeargummies_custom_excerpt_length( $length ) {
    return 20;
}
add_filter( 'excerpt_length', 'sleepybeargummies_custom_excerpt_length', 999 );