<?php
if ( ! defined('ABSPATH')) {die;}
// Control core classes for avoid errors
if( class_exists( 'CSF' ) ) {

  //
  // Set a unique slug-like ID
  $prefix = 'theme_options';

  /**
   *
   * @menu_parent argument examples.
   *
   * For Dashboard: 'index.php'
   * For Posts: 'edit.php'
   * For Media: 'upload.php'
   * For Pages: 'edit.php?post_type=page'
   * For Comments: 'edit-comments.php'
   * For Custom Post Types: 'edit.php?post_type=your_post_type'
   * For Appearance: 'themes.php'
   * For Plugins: 'plugins.php'
   * For Users: 'users.php'
   * For Tools: 'tools.php'
   * For Settings: 'options-general.php'
   *
   */
  CSF::createOptions( $prefix, array(
    'menu_title'      => 'Theme Options',
    'menu_slug'       => 'theme-options',
    'menu_type'       => 'submenu',
    'menu_parent'     => 'themes.php',
    'framework_title' => '<img src="'.get_stylesheet_directory_uri().'/assets/images/site-logo.png" width="150">&nbsp; RWS Framework <small>by Rigorous Web Services</small>',
    'show_reset_all'     => false,
    'show_reset_section' => false,
    'theme'               => 'light',
  ) );

  /**
   * General options
   */
  CSF::createSection( $prefix, array(
    'id'      => 'general_options',
    'title'   => 'General Options',
    'icon'    => 'fa fa-cog',
  ) );

  CSF::createSection( $prefix, array(
    'parent'      => 'general_options',
    'title'       => 'General Options',
    'icon'        => 'fa fa-square-o',
    'fields'      => array(
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Site Logo',
      ),
      array(
        'type'    => 'notice',
        'style'   => 'info',
        'content' => '<a href="'.site_url( '/wp-admin/customize.php' ).'">Click Here</a> to change the logo from customizer section.',
      ),
      array(
        'id'    =>  'product-text',
        'type'  =>  'wp_editor',
        'title' =>  'Subscription Page ',
        'media_buttons' => false,
      ),
    )
  ) );

  CSF::createSection( $prefix, array(
    'parent'      => 'general_options',
    'title'       => 'Custom JS Options',
    'icon'        => 'fa fa-square-o',
    'fields'      => array(
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Custom Js on Header',
      ),
      array(
        'id'       => 'header-javascript-editor',
        'type'     => 'code_editor',
        'title'    => 'Header Javascript Editor',
        'settings' => array(
          'theme'  => 'monokai',
          'mode'   => 'javascript',
        ),
        //'default'  => 'console.log("Hello world");',
      ),

    )
  ) );

  //
  // Header Section Fields
  //
  CSF::createSection( $prefix, array(
    'id'    => 'header_section',
    'title'  => 'Header Section',
    'icon'  => 'fa fa-cog',
  ) );

  CSF::createSection($prefix, array(
    'parent'    =>  'header_section',
    'title'     =>  'Top Header',
    'icon'      =>  'fa fa-header',
    'fields'    =>  array(
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Top Content',
      ),
      array(
        'id'    =>  'header-top',
        'type'  =>  'wp_editor',
        'title' =>  'Header Top Text',
        'media_buttons' => false,
      ),

    )
  ));

  //
  // Footer Section Fields
  //
  
  CSF::createSection( $prefix, array(
    'id'    => 'footer_section',
    'title'  => 'Footer Section',
    'icon'  => 'fa fa-cog',
  ) );

  CSF::createSection($prefix, array(
    'parent'    =>  'footer_section',
    'title'     =>  'Footer Contents',
    'icon'      =>  'fa fa-angle-right',
    'fields'    =>  array(
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Footer Content',
      ),
      array(
        'id'    =>  'footer_content',
        'type'  =>  'wp_editor',
        'title' =>  'Footer Content',
        'media_buttons' => false,
      ),
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Footer Link',
      ),
      array(
        'type'    => 'notice',
        'style'   => 'info',
        'content' => '<a href="'.site_url( '/wp-admin/nav-menus.php' ).'">Click Here</a> to create and assign menu to footer link on \'Display Location\' to show link on the footer bottom section.',
      ),
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Payment Options',
      ),
      array(
        'id'      => 'payment-options-sec-title',
        'type'    => 'text',
        'title'   => 'Section Title',
      ),
      array(
        'id'      =>  'payment-options-lists',
        'title'   =>  'Payment Options',
        'type'    =>  'group',
        'fields'  => array(
          array(
            'id'        => 'payment-icon',
            'type'      => 'icon',
            'title'     => 'Payment Icon',
            'default'   => 'fa fa-heart'
          ),
          array(
            'id'        => 'payment-url',
            'type'      => 'text',
            'title'     => 'URL',
          ),

        ),
      ),

    )
  ));

  CSF::createSection($prefix, array(
    'parent'    =>  'footer_section',
    'title'     =>  'Bottom Footer',
    'icon'      =>  'fa fa-at',
    'fields'    =>  array(
      array(
        'type'    => 'subheading',
        'style'   => 'info',
        'content' => 'Site Copyright Text',
      ),
      array(
        'id'    =>  'copyright',
        'type'  =>  'wp_editor',
        'title' =>  'Copyright Text',
        'media_buttons' => false,
        'desc'  => 'Use [year] tag to show dynamic year.',
      ),

    )
  ));

}